!!! note
    These pickers are built through a combination of [selectors](selectors.md) & [input](input.md) widgets, so in order to get a full understanding of the widgets functionality its recommend to the read aforementioned pages.

!!! info
    All pickers have a `.mini` CSS class which you can assign to these widgets, to convert them to a single line.

---

## DatePicker

```{.textual path="docs/examples/screenshot/date_picker_example.py"}

```

::: textual_timepiece.pickers.DatePicker

---


## DurationPicker

```{.textual path="docs/examples/screenshot/duration_picker_example.py"}

```


::: textual_timepiece.pickers.DurationPicker

---

## TimePicker

```{.textual path="docs/examples/screenshot/time_picker_example.py"}

```

::: textual_timepiece.pickers.TimePicker

---

## DateTimePicker

```{.textual path="docs/examples/screenshot/date_picker_example.py"}

```

::: textual_timepiece.pickers.DateTimePicker

---


## DateRangePicker

```{.textual path="docs/examples/screenshot/date_range_picker_example.py"}

```

::: textual_timepiece.pickers.DateRangePicker

---

## DateTimeRangePicker

```{.textual path="docs/examples/screenshot/datetime_range_picker_example.py"}

```

::: textual_timepiece.pickers.DateTimeRangePicker

---

## DateTimeDurationPicker

```{.textual path="docs/examples/screenshot/datetime_duration_picker_example.py"}

```

::: textual_timepiece.pickers.DateTimeDurationPicker
